==> beaker_py-2.0.0.dev20250425-py3-none-any.whl: beaker/exceptions.py <==
from grpc import RpcError
from requests.exceptions import HTTPError, RequestException

__all__ = [
    "BeakerError",
    "RpcError",
    "HTTPError",
    "BeakerClientError",
    "BeakerServerError",
    "BeakerServerUnavaibleError",
    "RequestException",
    "BeakerConfigurationError",
    "BeakerNotFoundError",
    "BeakerOrganizationNotFound",
    "BeakerUserNotFound",
    "BeakerWorkspaceNotFound",
    "BeakerClusterNotFound",
    "BeakerNodeNotFound",
    "BeakerBudgetNotFound",
    "BeakerGroupNotFound",
    "BeakerImageNotFound",
    "BeakerDatasetNotFound",
    "BeakerSecretNotFound",
    "BeakerExperimentNotFound",
    "BeakerWorkloadNotFound",
    "BeakerJobNotFound",
    "BeakerOrganizationNotSet",
    "BeakerWorkspaceNotSet",
    "BeakerPermissionsError",
    "BeakerNameConflictError",
    "BeakerDatasetConflict",
    "BeakerExperimentConflict",
    "BeakerImageConflict",
    "BeakerSecretConflict",
    "BeakerGroupConflict",
    "BeakerWorkspaceConflict",
    "BeakerDatasetWriteError",
    "BeakerUnexpectedEOFError",
]


class BeakerError(Exception):
    """Base class for all Beaker errors."""


class BeakerClientError(BeakerError):
    pass


class BeakerServerError(BeakerError):
    pass


class BeakerServerUnavaibleError(BeakerServerError):
    pass


class BeakerConfigurationError(BeakerError):
    """Raised when invalid fields are found in the config file."""


class BeakerNotFoundError(BeakerError):
    """Base class for not found errors."""


class BeakerOrganizationNotFound(BeakerNotFoundError):
    """Raised when a specified organization doesn't exist."""


class BeakerUserNotFound(BeakerNotFoundError):
    """Raised when a specified user doesn't exist."""


class BeakerWorkspaceNotFound(BeakerNotFoundError):
    """Raised when a specified workspace doesn't exist."""


class BeakerClusterNotFound(BeakerNotFoundError):
    """Raised when a specified cluster doesn't exist."""


class BeakerNodeNotFound(BeakerNotFoundError):
    """Raised when a specified node doesn't exist."""


class BeakerBudgetNotFound(BeakerNotFoundError):
    """Raised when a specified budget doesn't exist."""


class BeakerGroupNotFound(BeakerNotFoundError):
    """Raised when a specified group doesn't exist."""


class BeakerJobNotFound(BeakerNotFoundError):
    """Raised when a specified job doesn't exist."""


class BeakerExperimentNotFound(BeakerNotFoundError):
    """Raised when a specified experiment doesn't exist."""


class BeakerWorkloadNotFound(BeakerNotFoundError):
    """Raised when a specified workload doesn't exist."""


class BeakerImageNotFound(BeakerNotFoundError):
    """Raised when a specified image doesn't exist."""


class BeakerDatasetNotFound(BeakerNotFoundError):
    """Raised when a specified dataset doesn't exist."""


class BeakerSecretNotFound(BeakerNotFoundError):
    """Raised when a specified secret does not exist."""


class BeakerOrganizationNotSet(BeakerError):
    """Raised when the default organization is not set."""


class BeakerWorkspaceNotSet(BeakerError):
    """Raised when the default workspace is not set."""


class BeakerPermissionsError(BeakerError):
    pass


class BeakerNameConflictError(BeakerError):
    """Base error type for name conflict errors."""


class BeakerDatasetConflict(BeakerNameConflictError):
    pass


class BeakerExperimentConflict(BeakerNameConflictError):
    pass


class BeakerImageConflict(BeakerNameConflictError):
    pass


class BeakerSecretConflict(BeakerNameConflictError):
    pass


class BeakerGroupConflict(BeakerNameConflictError):
    pass


class BeakerWorkspaceConflict(BeakerNameConflictError):
    pass


class BeakerDatasetWriteError(BeakerError):
    pass


class BeakerUnexpectedEOFError(BeakerError):
    pass

==> beaker_py-2.0.1.dev20250428-py3-none-any.whl: beaker/exceptions.py <==
from grpc import RpcError
from requests.exceptions import HTTPError, RequestException

__all__ = [
    "BeakerError",
    "RpcError",
    "HTTPError",
    "BeakerClientError",
    "BeakerServerError",
    "BeakerServerUnavailableError",
    "RequestException",
    "BeakerConfigurationError",
    "BeakerNotFoundError",
    "BeakerOrganizationNotFound",
    "BeakerUserNotFound",
    "BeakerWorkspaceNotFound",
    "BeakerClusterNotFound",
    "BeakerNodeNotFound",
    "BeakerBudgetNotFound",
    "BeakerGroupNotFound",
    "BeakerImageNotFound",
    "BeakerDatasetNotFound",
    "BeakerSecretNotFound",
    "BeakerExperimentNotFound",
    "BeakerWorkloadNotFound",
    "BeakerJobNotFound",
    "BeakerOrganizationNotSet",
    "BeakerWorkspaceNotSet",
    "BeakerPermissionsError",
    "BeakerNameConflictError",
    "BeakerDatasetConflict",
    "BeakerExperimentConflict",
    "BeakerImageConflict",
    "BeakerSecretConflict",
    "BeakerGroupConflict",
    "BeakerWorkspaceConflict",
    "BeakerDatasetWriteError",
    "BeakerUnexpectedEOFError",
]


class BeakerError(Exception):
    """Base class for all Beaker errors."""


class BeakerClientError(BeakerError):
    pass


class BeakerServerError(BeakerError):
    pass


class BeakerServerUnavailableError(BeakerServerError):
    pass


class BeakerConfigurationError(BeakerError):
    """Raised when invalid fields are found in the config file."""


class BeakerNotFoundError(BeakerError):
    """Base class for not found errors."""


class BeakerOrganizationNotFound(BeakerNotFoundError):
    """Raised when a specified organization doesn't exist."""


class BeakerUserNotFound(BeakerNotFoundError):
    """Raised when a specified user doesn't exist."""


class BeakerWorkspaceNotFound(BeakerNotFoundError):
    """Raised when a specified workspace doesn't exist."""


class BeakerClusterNotFound(BeakerNotFoundError):
    """Raised when a specified cluster doesn't exist."""


class BeakerNodeNotFound(BeakerNotFoundError):
    """Raised when a specified node doesn't exist."""


class BeakerBudgetNotFound(BeakerNotFoundError):
    """Raised when a specified budget doesn't exist."""


class BeakerGroupNotFound(BeakerNotFoundError):
    """Raised when a specified group doesn't exist."""


class BeakerJobNotFound(BeakerNotFoundError):
    """Raised when a specified job doesn't exist."""


class BeakerExperimentNotFound(BeakerNotFoundError):
    """Raised when a specified experiment doesn't exist."""


class BeakerWorkloadNotFound(BeakerNotFoundError):
    """Raised when a specified workload doesn't exist."""


class BeakerImageNotFound(BeakerNotFoundError):
    """Raised when a specified image doesn't exist."""


class BeakerDatasetNotFound(BeakerNotFoundError):
    """Raised when a specified dataset doesn't exist."""


class BeakerSecretNotFound(BeakerNotFoundError):
    """Raised when a specified secret does not exist."""


class BeakerOrganizationNotSet(BeakerError):
    """Raised when the default organization is not set."""


class BeakerWorkspaceNotSet(BeakerError):
    """Raised when the default workspace is not set."""


class BeakerPermissionsError(BeakerError):
    pass


class BeakerNameConflictError(BeakerError):
    """Base error type for name conflict errors."""


class BeakerDatasetConflict(BeakerNameConflictError):
    pass


class BeakerExperimentConflict(BeakerNameConflictError):
    pass


class BeakerImageConflict(BeakerNameConflictError):
    pass


class BeakerSecretConflict(BeakerNameConflictError):
    pass


class BeakerGroupConflict(BeakerNameConflictError):
    pass


class BeakerWorkspaceConflict(BeakerNameConflictError):
    pass


class BeakerDatasetWriteError(BeakerError):
    pass


class BeakerUnexpectedEOFError(BeakerError):
    pass
